# Relative Mode

This package contains code for relative mode estimation from audio signal, which refers to the degree of how major or minor does the music sound appears to be in a given time. It is based on key-finding algoritm principles and takes the difference between the strongest major key and the strongest minor key to be the index of relative mode. Relative mode can vary from -1.0 (clearly in minor) to + 1.0 (clearly in major). 

It is fully documented in a manuscript titled "Major-minorness in Tonal music – Evaluation of Relative Mode Estimation using Expert Ratings and Audio-Based Key-finding Principles" by Tuomas Eerola and Michael Schutz (in review). This manuscript documents the evaluation of the algorithm with expert data and three sets of data.



